<?php

namespace Litecms\Addetails\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Addetails\Models\Addetails;

class AddetailsPolicy
{

    /**
     * Determine if the given user can view the addetails.
     *
     * @param UserPolicy $user
     * @param Addetails $addetails
     *
     * @return bool
     */
    public function view(UserPolicy $user, Addetails $addetails)
    {
        if ($user->canDo('addetails.addetails.view') && $user->isAdmin()) {
            return true;
        }

        return $addetails->user_id == user_id() && $addetails->user_type == user_type();
    }

    /**
     * Determine if the given user can create a addetails.
     *
     * @param UserPolicy $user
     * @param Addetails $addetails
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('addetails.addetails.create');
    }

    /**
     * Determine if the given user can update the given addetails.
     *
     * @param UserPolicy $user
     * @param Addetails $addetails
     *
     * @return bool
     */
    public function update(UserPolicy $user, Addetails $addetails)
    {
        if ($user->canDo('addetails.addetails.edit') && $user->isAdmin()) {
            return true;
        }

        return $addetails->user_id == user_id() && $addetails->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given addetails.
     *
     * @param UserPolicy $user
     * @param Addetails $addetails
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Addetails $addetails)
    {
        return $addetails->user_id == user_id() && $addetails->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given addetails.
     *
     * @param UserPolicy $user
     * @param Addetails $addetails
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Addetails $addetails)
    {
        if ($user->canDo('addetails.addetails.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given addetails.
     *
     * @param UserPolicy $user
     * @param Addetails $addetails
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Addetails $addetails)
    {
        if ($user->canDo('addetails.addetails.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
